@@ -1,7 +1,6 @@
 import os
 
-requests_code = '''
-"""
+requests_code = '''"""
 This is not the real requests Python module
 but a partial API implementation for Basthon.
 """
